"use strict";
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/environment.ts
var environment_exports = {};
__export(environment_exports, {
  loadEnv: () => loadEnv,
  writeEnv: () => writeEnv
});
module.exports = __toCommonJS(environment_exports);

// src/environment/load-env.ts
var import_node_path = require("path");

// src/terminal/ascii.ts
var import_yoctocolors = require("yoctocolors");

// src/terminal/mask-tokens.ts
var maskTokens = (output) => {
  return output.replace(/sm_(pat|aat|sat)_[0-9a-zA-Z]+/g, "***");
};

// src/terminal/cancel.ts
var import_yoctocolors2 = require("yoctocolors");
var CancelError = class extends Error {
};
var cancel = (msg) => {
  console.log("");
  console.log((0, import_yoctocolors2.inverse)((0, import_yoctocolors2.redBright)(maskTokens(msg))));
  console.log("");
  throw new CancelError(msg);
};

// src/terminal/execute-command.ts
var import_node_child_process = require("child_process");

// src/terminal/intro.ts
var import_yoctocolors3 = require("yoctocolors");

// src/terminal/note.ts
var import_yoctocolors4 = require("yoctocolors");

// src/terminal/outro.ts
var import_yoctocolors5 = require("yoctocolors");

// src/terminal/spinner.ts
var import_is_in_ci = __toESM(require("is-in-ci"), 1);
var import_yocto_spinner = __toESM(require("yocto-spinner"), 1);
var import_yoctocolors6 = require("yoctocolors");

// src/terminal/table.ts
var import_console_table_printer = require("console-table-printer");
var import_yoctocolors7 = require("yoctocolors");

// src/validation/validate.ts
var import_zod = require("zod");
function validate(schema, value) {
  try {
    return schema.parse(value);
  } catch (error) {
    if (error instanceof import_zod.ZodError) {
      const formattedErrors = error.errors.map((err) => `- ${err.path.join(".")}: ${err.message}`).join("\n");
      throw new Error(`Validation error${error.errors.length > 1 ? "s" : ""}:
${formattedErrors}`);
    }
    throw error;
  }
}

// src/validation/access-token.schema.ts
var import_zod2 = require("zod");
var ApplicationAccessTokenSchema = import_zod2.z.string().regex(/^sm_aat_.*$/);
var PersonalAccessTokenSchema = import_zod2.z.string().regex(/^sm_pat_.*$/);
var AccessTokenSchema = import_zod2.z.string().regex(/^sm_pat_.*|sm_aat_.*$/);

// src/json.ts
function tryParseJson(value, defaultValue = null) {
  try {
    const parsed = JSON.parse(value);
    if (parsed === void 0 || parsed === null) {
      return defaultValue;
    }
    return parsed;
  } catch (err) {
    return defaultValue;
  }
}

// src/validation/dot-env.schema.ts
var import_zod5 = require("zod");

// src/validation/unique-name.schema.ts
var import_zod3 = require("zod");
var UniqueNameSchema = import_zod3.z.string().regex(/^[a-z0-9-]+$/);

// src/validation/url.schema.ts
var import_zod4 = require("zod");
var UrlSchema = import_zod4.z.string().url();
var UrlPathSchema = import_zod4.z.string().regex(/^\/(?:[a-zA-Z0-9-_]+(?:\/[a-zA-Z0-9-_]+)*\/?)?$/, {
  message: "Invalid URL path format. Must start with '/' and can contain letters, numbers, hyphens, and underscores."
});
var UrlOrPathSchema = import_zod4.z.union([UrlSchema, UrlPathSchema]);

// src/validation/dot-env.schema.ts
var DotEnvSchema = import_zod5.z.object({
  /** Base URL of the SettleMint platform instance */
  SETTLEMINT_INSTANCE: UrlSchema.default("https://console.settlemint.com"),
  /** Application access token for authenticating with SettleMint services */
  SETTLEMINT_ACCESS_TOKEN: ApplicationAccessTokenSchema.optional(),
  /** @internal */
  SETTLEMINT_PERSONAL_ACCESS_TOKEN: PersonalAccessTokenSchema.optional(),
  /** Unique name of the workspace */
  SETTLEMINT_WORKSPACE: UniqueNameSchema.optional(),
  /** Unique name of the application */
  SETTLEMINT_APPLICATION: UniqueNameSchema.optional(),
  /** Unique name of the blockchain network */
  SETTLEMINT_BLOCKCHAIN_NETWORK: UniqueNameSchema.optional(),
  /** Unique name of the blockchain node */
  SETTLEMINT_BLOCKCHAIN_NODE: UniqueNameSchema.optional(),
  /** Unique name of the load balancer */
  SETTLEMINT_LOAD_BALANCER: UniqueNameSchema.optional(),
  /** Unique name of the Hasura instance */
  SETTLEMINT_HASURA: UniqueNameSchema.optional(),
  /** Endpoint URL for the Hasura GraphQL API */
  SETTLEMINT_HASURA_ENDPOINT: UrlSchema.optional(),
  /** Admin secret for authenticating with Hasura */
  SETTLEMINT_HASURA_ADMIN_SECRET: import_zod5.z.string().optional(),
  /** Database connection URL for Hasura */
  SETTLEMINT_HASURA_DATABASE_URL: import_zod5.z.string().optional(),
  /** Unique name of The Graph instance */
  SETTLEMINT_THEGRAPH: UniqueNameSchema.optional(),
  /** Array of endpoint URLs for The Graph subgraphs */
  SETTLEMINT_THEGRAPH_SUBGRAPHS_ENDPOINTS: import_zod5.z.preprocess(
    (value) => tryParseJson(value, []),
    import_zod5.z.array(UrlSchema).optional()
  ),
  /** Default The Graph subgraph to use */
  SETTLEMINT_THEGRAPH_DEFAULT_SUBGRAPH: import_zod5.z.string().optional(),
  /** Unique name of the Smart Contract Portal instance */
  SETTLEMINT_PORTAL: UniqueNameSchema.optional(),
  /** GraphQL endpoint URL for the Portal */
  SETTLEMINT_PORTAL_GRAPHQL_ENDPOINT: UrlSchema.optional(),
  /** REST endpoint URL for the Portal */
  SETTLEMINT_PORTAL_REST_ENDPOINT: UrlSchema.optional(),
  /** Unique name of the HD private key */
  SETTLEMINT_HD_PRIVATE_KEY: UniqueNameSchema.optional(),
  /** Unique name of the accessible private key */
  SETTLEMINT_ACCESSIBLE_PRIVATE_KEY: UniqueNameSchema.optional(),
  /** Unique name of the MinIO instance */
  SETTLEMINT_MINIO: UniqueNameSchema.optional(),
  /** Endpoint URL for MinIO */
  SETTLEMINT_MINIO_ENDPOINT: UrlSchema.optional(),
  /** Access key for MinIO authentication */
  SETTLEMINT_MINIO_ACCESS_KEY: import_zod5.z.string().optional(),
  /** Secret key for MinIO authentication */
  SETTLEMINT_MINIO_SECRET_KEY: import_zod5.z.string().optional(),
  /** Unique name of the IPFS instance */
  SETTLEMINT_IPFS: UniqueNameSchema.optional(),
  /** API endpoint URL for IPFS */
  SETTLEMINT_IPFS_API_ENDPOINT: UrlSchema.optional(),
  /** Pinning service endpoint URL for IPFS */
  SETTLEMINT_IPFS_PINNING_ENDPOINT: UrlSchema.optional(),
  /** Gateway endpoint URL for IPFS */
  SETTLEMINT_IPFS_GATEWAY_ENDPOINT: UrlSchema.optional(),
  /** Unique name of the custom deployment */
  SETTLEMINT_CUSTOM_DEPLOYMENT: UniqueNameSchema.optional(),
  /** Endpoint URL for the custom deployment */
  SETTLEMINT_CUSTOM_DEPLOYMENT_ENDPOINT: UrlSchema.optional(),
  /** Unique name of the Blockscout instance */
  SETTLEMINT_BLOCKSCOUT: UniqueNameSchema.optional(),
  /** GraphQL endpoint URL for Blockscout */
  SETTLEMINT_BLOCKSCOUT_GRAPHQL_ENDPOINT: UrlSchema.optional(),
  /** UI endpoint URL for Blockscout */
  SETTLEMINT_BLOCKSCOUT_UI_ENDPOINT: UrlSchema.optional(),
  /** Name of the new project being created */
  SETTLEMINT_NEW_PROJECT_NAME: import_zod5.z.string().optional()
});
var DotEnvSchemaPartial = DotEnvSchema.partial();

// src/validation/id.schema.ts
var import_zod6 = require("zod");
var IdSchema = import_zod6.z.union([
  import_zod6.z.string().uuid(),
  // PostgreSQL UUID
  import_zod6.z.string().regex(/^[0-9a-fA-F]{24}$/)
  // MongoDB ObjectID
]);

// src/environment/load-env.ts
var import_dotenvx = require("@dotenvx/dotenvx");
async function loadEnv(validateEnv, prod, path = process.cwd()) {
  return loadEnvironmentEnv(validateEnv, !!prod, path);
}
async function loadEnvironmentEnv(validateEnv, prod, path = process.cwd()) {
  if (prod) {
    process.env.NODE_ENV = "production";
  }
  let { parsed } = (0, import_dotenvx.config)({
    convention: "nextjs",
    logLevel: "error",
    overload: true,
    quiet: true,
    path: [(0, import_node_path.join)(path, ".env"), (0, import_node_path.join)(path, ".env.local")]
  });
  if (!parsed) {
    parsed = {};
  }
  const defaultEnv = Object.fromEntries(
    Object.entries(process.env).filter(([_, value]) => typeof value === "string" && value !== "")
  );
  try {
    return validate(validateEnv ? DotEnvSchema : DotEnvSchemaPartial, {
      ...parsed,
      ...defaultEnv
    });
  } catch (error) {
    cancel(error.message);
    return {};
  }
}

// src/environment/write-env.ts
var import_promises3 = require("fs/promises");
var import_node_path4 = require("path");

// src/filesystem/project-root.ts
var import_node_path2 = require("path");
var import_find_up = require("find-up");
async function projectRoot(fallbackToCwd = false, cwd) {
  const packageJsonPath = await (0, import_find_up.findUp)("package.json", { cwd });
  if (!packageJsonPath) {
    if (fallbackToCwd) {
      return process.cwd();
    }
    throw new Error("Unable to find project root (no package.json found)");
  }
  return (0, import_node_path2.dirname)(packageJsonPath);
}

// src/filesystem/exists.ts
var import_promises = require("fs/promises");
async function exists(path) {
  try {
    await (0, import_promises.stat)(path);
    return true;
  } catch {
    return false;
  }
}

// src/filesystem/mono-repo.ts
var import_promises2 = require("fs/promises");
var import_node_path3 = require("path");
var import_find_up2 = require("find-up");
var import_glob = require("glob");
async function findMonoRepoRoot(startDir) {
  const lockFilePath = await (0, import_find_up2.findUp)(["package-lock.json", "yarn.lock", "pnpm-lock.yaml", "bun.lockb", "bun.lock"], {
    cwd: startDir
  });
  if (lockFilePath) {
    const packageJsonPath = (0, import_node_path3.join)((0, import_node_path3.dirname)(lockFilePath), "package.json");
    const hasWorkSpaces = await packageJsonHasWorkspaces(packageJsonPath);
    return hasWorkSpaces ? (0, import_node_path3.dirname)(lockFilePath) : null;
  }
  let currentDir = startDir;
  while (currentDir !== "/") {
    const packageJsonPath = (0, import_node_path3.join)(currentDir, "package.json");
    if (await packageJsonHasWorkspaces(packageJsonPath)) {
      return currentDir;
    }
    const parentDir = (0, import_node_path3.dirname)(currentDir);
    if (parentDir === currentDir) {
      break;
    }
    currentDir = parentDir;
  }
  return null;
}
async function findMonoRepoPackages(projectDir) {
  try {
    const monoRepoRoot = await findMonoRepoRoot(projectDir);
    if (!monoRepoRoot) {
      return [projectDir];
    }
    const packageJsonPath = (0, import_node_path3.join)(monoRepoRoot, "package.json");
    const packageJson = tryParseJson(await (0, import_promises2.readFile)(packageJsonPath, "utf-8"));
    const workspaces = packageJson?.workspaces ?? [];
    const packagePaths = await Promise.all(
      workspaces.map(async (workspace) => {
        const matches = await (0, import_glob.glob)((0, import_node_path3.join)(monoRepoRoot, workspace, "package.json"));
        return matches.map((match) => (0, import_node_path3.join)(match, ".."));
      })
    );
    const allPaths = packagePaths.flat();
    return allPaths.length === 0 ? [projectDir] : [monoRepoRoot, ...allPaths];
  } catch (error) {
    return [projectDir];
  }
}
async function packageJsonHasWorkspaces(packageJsonPath) {
  if (await exists(packageJsonPath)) {
    const packageJson = tryParseJson(await (0, import_promises2.readFile)(packageJsonPath, "utf-8"));
    if (packageJson?.workspaces && Array.isArray(packageJson?.workspaces) && packageJson?.workspaces.length > 0) {
      return true;
    }
  }
  return false;
}

// src/environment/write-env.ts
var import_dotenvx2 = require("@dotenvx/dotenvx");
var import_deepmerge_ts = require("deepmerge-ts");
async function writeEnv({
  prod,
  env,
  secrets,
  cwd
}) {
  const projectDir = await projectRoot(true, cwd);
  if (prod) {
    process.env.NODE_ENV = "production";
  }
  const targetDirs = await findMonoRepoPackages(projectDir);
  await Promise.all(
    targetDirs.map(async (dir) => {
      const envFile = (0, import_node_path4.join)(
        dir,
        secrets ? `.env${prod ? ".production" : ""}.local` : `.env${prod ? ".production" : ""}`
      );
      let { parsed: currentEnv } = await exists(envFile) ? (0, import_dotenvx2.config)({
        path: envFile,
        logLevel: "error",
        quiet: true
      }) : { parsed: {} };
      if (!currentEnv) {
        currentEnv = {};
      }
      const mergedEnv = (0, import_deepmerge_ts.deepmerge)(pruneCurrentEnv(currentEnv, env), env);
      await (0, import_promises3.writeFile)(envFile, stringify(mergedEnv));
    })
  );
}
var quote = /[\s"'#]/;
function stringifyPair([key, val]) {
  if (val === void 0) {
    return void 0;
  }
  if (val === null) {
    return `${key}=""`;
  }
  const type = typeof val;
  if (type === "string") {
    return `${key}=${quote.test(val) ? JSON.stringify(val) : val}`;
  }
  if (type === "boolean" || type === "number") {
    return `${key}=${val}`;
  }
  if (type === "object") {
    return `${key}=${JSON.stringify(val)}`;
  }
  throw new Error(`Unsupported type for key "${key}": ${type}`);
}
function stringify(obj) {
  return Object.entries(obj).sort(([a], [b]) => a.localeCompare(b)).map(stringifyPair).filter((value) => value !== void 0).join("\n");
}
function pruneCurrentEnv(currentEnv, env) {
  const dotEnvKeys = Object.keys(DotEnvSchema.shape);
  return Object.fromEntries(
    Object.entries(currentEnv).filter(([key]) => {
      if (dotEnvKeys.includes(key) && !env[key]) {
        return false;
      }
      return true;
    })
  );
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  loadEnv,
  writeEnv
});
//# sourceMappingURL=environment.cjs.map